#
# spec file for package python-liblarch
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2012 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         _name liblarch
%define         _name_gtk liblarch_gtk
Name:           python-liblarch
Version:        3.2.0
Release:        2.5
Summary:        A Python library to handle data structure
License:        LGPL-3.0-or-later
URL:            https://live.gnome.org/liblarch
Source:         https://github.com/getting-things-gnome/%{_name}/archive/v%{version}.tar.gz
# PATCH-FIX-UPSTREAM gh#getting-things-gnome/liblarch#36
Patch0:         use-pytest.patch
BuildRequires:  %{python_module gobject-Gdk}
BuildRequires:  %{python_module gobject}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  xvfb-run
BuildRequires:  typelib(Gtk) >= 3.0
Requires:       python-gobject
Requires:       python-gobject-Gdk
BuildArch:      noarch
%python_subpackages

%description
Liblarch is a Python library built to handle data structure such
are lists, trees and acyclic graphs (tree where nodes can have multiple
parents)

%package gtk
Summary:        GTK bindings for liblarch
Requires:       %{name} = %{version}
Requires:       python-gobject
Requires:       typelib(Gtk) >= 3.0

%description gtk
Liblarch is a Python library built to handle data structure such
are lists, trees and acyclic graphs (tree where nodes can have multiple
parents)

This package provides GTK bindings for liblarch.

%prep
%autosetup -p1 -n %{_name}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# TESTS fail with segf, local execution works
%check
%{python_expand #
xvfb-run -a $python ./run-tests
}

%files %{python_files}
%license LICENSE
%doc README.md AUTHORS
%{python_sitelib}/%{_name}
%{python_sitelib}/%{_name}-%{version}.dist-info

%files %{python_files gtk}
%license LICENSE
%{python_sitelib}/%{_name_gtk}/

%changelog
* Tue Mar 26 2024 Daniel Garcia <daniel.garcia@suse.com>
- Switch to autosetup and pyproject macros
- Run tests with xvfb-run, and use upstream's run-tests script
- Require python-gobject-Gdk to work for all python versions
  bsc#1221961
- Add patch use-pytest.patch:
  * Switch from nose to pytest.
* Mon Jan 22 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.0:
  * Provide a fix for collapsing/expanding future (not-yet-
    created) nodes
    This prevents a TypeError under various circumstances,
    which made GTG's TreeView display inconsistent
    search/filtering results.
  * Clarify, in the README file, that liblarch is LGPL v3 "or
    later"
  * Fix Pytest deprecation warnings
  * Provide an optimized way to refresh filtered items
    This provides better performance for GTG in particular
  * Replace calls to the pep8 executable by pycodestyle
  * Disable building with Python 2
  * Fix drag & drop from one GTK TreeView widget to another
  * Handle cases where the tree should and shouldn't be re-
    filtered
  * Improved PyGI (GObject introspection) compatibility
  * Improved code quality and PEP 8 compliance
- drop libarch-py2compat.patch (obsolete as upstream is >= 3.5)
- reenable tests
* Wed Apr 15 2020 Paolo Stivanin <info@paolostivanin.com>
- Remove nose dep as tests are not executed
* Tue Aug  7 2018 tchvatal@suse.com
- Reflect deps properly on what is needed
- Add patch to work properly under py2:
  * libarch-py2compat.patch
* Sat Jul 28 2018 jengelh@inai.de
- Trim bias from descriptions.
* Mon Jun 25 2018 mcepl@suse.com
- Clean up SPEC file
- Upgrade to 3.0 ... just minor upgrades, py3k port
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Sat Jan 26 2013 zaitor@opensuse.org
- Update to version 2.1.0:
  + Removed completely the "transparency" property.
  + Added a new object : viewcount
  + The version number of liblarch will now be the API number + a
    number.
- Added liblarch_gtk as a subpackage, it is no longer released as a
  separate sourcepackage.
* Thu Jan  3 2013 toddrme2178@gmail.com
- Fix building on SLES 11
* Tue Feb 28 2012 cfarrell@suse.com
- license update: LGPL-3.0+
  See README and License files. This package is LGPL-3.0+
* Wed Feb 15 2012 dimstar@opensuse.org
- Initial package, version 0.1.0.
